@@ -44,7 +44,7 @@ struct _EphyAboutHandler {
   EphySMaps *smaps;
 };
 
-G_DEFINE_TYPE (EphyAboutHandler, ephy_about_handler, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (EphyAboutHandler, ephy_about_handler, G_TYPE_OBJECT)
 
 
 #define EPHY_ABOUT_OVERVIEW_MAX_ITEMS 9
@@ -246,10 +246,14 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
                                  GAsyncResult           *result,
                                  WebKitURISchemeRequest *request)
 {
+  WebKitWebView *view;
   GString *data_str;
   gsize data_length;
   GList *applications, *p;
 
+  view = webkit_uri_scheme_request_get_web_view (request);
+  ephy_web_view_register_message_handler (EPHY_WEB_VIEW (view), EPHY_WEB_VIEW_ABOUT_APPS_MESSAGE_HANDLER, EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_CURRENT_PAGE);
+
   data_str = g_string_new (NULL);
   applications = g_task_propagate_pointer (G_TASK (result), NULL);
 
@@ -258,15 +262,14 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
                             "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
                             "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
                             "<script>"
-                            "  function deleteWebApp(appID) {"
-                            "    window.webkit.messageHandlers.aboutApps.postMessage(appID);"
-                            "    var row = document.getElementById(appID);"
-                            "    row.parentNode.removeChild(row);"
+                            "  function deleteWebApp(appID, appName) {"
+                            "    window.webkit.messageHandlers.aboutApps.postMessage({app: appID, name: appName, page: %" G_GUINT64_FORMAT "});"
                             "  }"
                             "</script>"
                             "</head><div id=\"applications\"><body class=\"applications-body\"><h1>%s</h1>"
                             "<p>%s</p>",
                             _("Apps"),
+                            webkit_web_view_get_page_id (view),
                             _("Apps"),
                             _("List of installed web apps"));
 
@@ -302,9 +305,9 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
       /* Most of these fields are at least semi-trusted. The app ID was chosen
        * by ephy so it's safe. The icon URL could be changed by the user to
        * something else after web app creation, though, so better not fully
-       * trust it. Then the app name and the main URL could contain contain
-       * anything at all, so those need to be encoded for sure. Install date
-       * should be fine because it's constructed by Epiphany.
+       * trust it. Then the app name and the main URL could contain anything
+       * at all, so those need to be encoded for sure. Install date should be
+       * fine because it's constructed by Epiphany.
        */
       encoded_icon_path = ephy_encode_for_html_attribute (icon_path);
       encoded_name = ephy_encode_for_html_entity (app->name);
@@ -313,10 +316,10 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
                               "<tbody><tr id =\"%s\">"
                               "<td class=\"icon\"><img width=64 height=64 src=\"file://%s\"></img></td>"
                               "<td class=\"data\"><div class=\"appname\">%s</div><div class=\"appurl\">%s</div></td>"
-                              "<td class=\"input\"><input type=\"button\" value=\"%s\" onclick=\"deleteWebApp('%s');\" "
+                              "<td class=\"input\"><input type=\"button\" value=\"%s\" onclick=\"deleteWebApp('%s', '%s');\" "
                               "class=\"destructive-action\"></td>"
                               "<td class=\"date\">%s <br /> %s</td></tr></tbody>",
-                              app->id, encoded_icon_path, encoded_name, encoded_url, _("Delete"), app->id,
+                              app->id, encoded_icon_path, encoded_name, encoded_url, _("Delete"), app->id, encoded_name,
                               /* Note for translators: this refers to the installation date. */
                               _("Installed on:"), install_date);
     }
