@@ -95,7 +95,6 @@ G_DEFINE_FINAL_TYPE (EphyShell, ephy_shell, EPHY_TYPE_EMBED_SHELL)
  * @startup_mode: An #EphyStartupMode (new tab or new window)
  * @session_filename: A session to restore.
  * @arguments: A %NULL-terminated array of URLs and file URIs to be opened.
- * @user_time: The user time when the EphyShell startup was invoked.
  *
  * Creates a new startup context. All string parameters, including
  * @arguments, are copied.
@@ -105,15 +104,13 @@ G_DEFINE_FINAL_TYPE (EphyShell, ephy_shell, EPHY_TYPE_EMBED_SHELL)
 EphyShellStartupContext *
 ephy_shell_startup_context_new (EphyStartupMode   startup_mode,
                                 char             *session_filename,
-                                char            **arguments,
-                                guint32           user_time)
+                                char            **arguments)
 {
   EphyShellStartupContext *ctx = g_new0 (EphyShellStartupContext, 1);
 
   ctx->startup_mode = startup_mode;
   ctx->session_filename = g_strdup (session_filename);
   ctx->arguments = g_strdupv (arguments);
-  ctx->user_time = user_time;
 
   return ctx;
 }
@@ -141,8 +138,7 @@ ephy_shell_startup_continue (EphyShell               *shell,
 
   if (ctx->session_filename != NULL) {
     g_assert (session != NULL);
-    ephy_session_load (session, (const char *)ctx->session_filename,
-                       ctx->user_time, NULL, NULL, NULL);
+    ephy_session_load (session, (const char *)ctx->session_filename, NULL, NULL, NULL);
   } else if (new_window_option && shell->remote_startup_context) {
     char *homepage_url = g_settings_get_string (EPHY_SETTINGS_MAIN, EPHY_PREFS_HOMEPAGE_URL);
     const char *default_uris[] = { homepage_url, NULL };
@@ -155,7 +151,7 @@ ephy_shell_startup_continue (EphyShell               *shell,
       /* has been used, then use the default_uris list to open the homepage */
       uris = default_uris;
 
-    ephy_shell_open_uris (shell, uris, ctx->startup_mode, ctx->user_time);
+    ephy_shell_open_uris (shell, uris, ctx->startup_mode);
     g_free (homepage_url);
   } else if (active_window && (!ctx->arguments || mode == EPHY_EMBED_SHELL_MODE_APPLICATION)) {
     /* If the application already has an active window and: */
@@ -170,8 +166,7 @@ ephy_shell_startup_continue (EphyShell               *shell,
   } else if (ctx->arguments || !session) {
     /* Don't queue any window openings if no extra arguments given, */
     /* since session autoresume will open one for us. */
-    ephy_shell_open_uris (shell, (const char **)ctx->arguments,
-                          ctx->startup_mode, ctx->user_time);
+    ephy_shell_open_uris (shell, (const char **)ctx->arguments, ctx->startup_mode);
   } else if (ephy_shell_get_n_windows (shell) == 0) {
     EphyWindow *window = ephy_window_new ();
     ephy_link_open (EPHY_LINK (window), NULL, NULL, EPHY_LINK_HOME_PAGE);
@@ -240,6 +235,18 @@ import_passwords (GSimpleAction *action,
   window_cmd_import_passwords (NULL, NULL, EPHY_WINDOW (window));
 }
 
+static void
+export_passwords (GSimpleAction *action,
+                  GVariant      *parameter,
+                  gpointer       user_data)
+{
+  GtkWindow *window;
+
+  window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
+
+  window_cmd_export_passwords (NULL, NULL, EPHY_WINDOW (window));
+}
+
 static void
 show_history (GSimpleAction *action,
               GVariant      *parameter,
@@ -264,6 +271,18 @@ show_firefox_sync (GSimpleAction *action,
   window_cmd_show_firefox_sync (NULL, NULL, EPHY_WINDOW (window));
 }
 
+static void
+show_clear_data_view (GSimpleAction *action,
+                      GVariant      *parameter,
+                      gpointer       user_data)
+{
+  GtkWindow *window;
+
+  window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
+
+  window_cmd_show_clear_data_view (NULL, NULL, EPHY_WINDOW (window));
+}
+
 static void
 show_preferences (GSimpleAction *action,
                   GVariant      *parameter,
@@ -370,8 +389,10 @@ static GActionEntry app_entries[] = {
   { "import-bookmarks", import_bookmarks, NULL, NULL, NULL },
   { "export-bookmarks", export_bookmarks, NULL, NULL, NULL },
   { "import-passwords", import_passwords, NULL, NULL, NULL },
+  { "export-passwords", export_passwords, NULL, NULL, NULL },
   { "history", show_history, NULL, NULL, NULL },
   { "firefox-sync-dialog", show_firefox_sync, NULL, NULL, NULL },
+  { "clear-data-view", show_clear_data_view, NULL, NULL, NULL},
   { "preferences", show_preferences, NULL, NULL, NULL },
   { "shortcuts", show_shortcuts, NULL, NULL, NULL },
   { "help", show_help, NULL, NULL, NULL },
@@ -390,6 +411,7 @@ static GActionEntry non_incognito_extra_app_entries[] = {
 static GActionEntry app_mode_app_entries[] = {
   { "new-window", new_window, NULL, NULL, NULL },
   { "history", show_history, NULL, NULL, NULL },
+  { "clear-data-view", show_clear_data_view, NULL, NULL, NULL},
   { "preferences", show_preferences, NULL, NULL, NULL },
   { "about", show_about, NULL, NULL, NULL },
   { "quit", quit_application, NULL, NULL, NULL },
@@ -589,6 +611,7 @@ ephy_shell_startup (GApplication *application)
   /* Actions that are available in both app mode and browser mode */
   set_accel_for_action (shell, "app.new-window", "<Primary>n");
   set_accel_for_action (shell, "app.history", "<Primary>h");
+  set_accel_for_action (shell, "app.clear-data-view", "<Primary><Shift>Delete");
   set_accel_for_action (shell, "app.preferences", "<Primary>comma");
   set_accel_for_action (shell, "app.quit", "<Primary>q");
 }
@@ -692,9 +715,7 @@ ephy_shell_activate (GApplication *application)
      * commands in session_load_cb. Otherwise, run them now.
      */
     if (session) {
-      ephy_session_resume (session,
-                           shell->local_startup_context->user_time,
-                           NULL, session_load_cb, shell->local_startup_context);
+      ephy_session_resume (session, NULL, session_load_cb, shell->local_startup_context);
     } else
       ephy_shell_startup_continue (shell, shell->local_startup_context);
   } else {
@@ -718,59 +739,53 @@ typedef enum {
   CTX_STARTUP_MODE,
   CTX_SESSION_FILENAME,
   CTX_ARGUMENTS,
-  CTX_USER_TIME
 } CtxEnum;
 
 static void
 ephy_shell_add_platform_data (GApplication    *application,
                               GVariantBuilder *builder)
 {
-  EphyShell *app;
+  EphyShell *app = EPHY_SHELL (application);
   EphyShellStartupContext *ctx;
-  GVariantBuilder *ctx_builder;
+  GVariantBuilder ctx_builder;
 
-  app = EPHY_SHELL (application);
+  G_APPLICATION_CLASS (ephy_shell_parent_class)->add_platform_data (application, builder);
 
-  G_APPLICATION_CLASS (ephy_shell_parent_class)->add_platform_data (application,
-                                                                    builder);
+  if (!app->local_startup_context)
+    return;
 
-  if (app->local_startup_context) {
-    /*
-     * We create an array variant that contains only the elements in
-     * ctx that are non-NULL.
-     */
-    ctx_builder = g_variant_builder_new (G_VARIANT_TYPE_ARRAY);
-    ctx = app->local_startup_context;
+  /*
+   * We create an array variant that contains only the elements in
+   * ctx that are non-NULL.
+   */
 
-    if (ctx->startup_mode)
-      g_variant_builder_add (ctx_builder, "{iv}",
-                             CTX_STARTUP_MODE,
-                             g_variant_new_byte (ctx->startup_mode));
+  ctx = app->local_startup_context;
+  if (ctx->startup_mode == 0 && !ctx->session_filename && !ctx->arguments)
+    return;
 
-    if (ctx->session_filename)
-      g_variant_builder_add (ctx_builder, "{iv}",
-                             CTX_SESSION_FILENAME,
-                             g_variant_new_string (ctx->session_filename));
+  g_variant_builder_init (&ctx_builder, G_VARIANT_TYPE_ARRAY);
+  if (ctx->startup_mode)
+    g_variant_builder_add (&ctx_builder, "{iv}",
+                           CTX_STARTUP_MODE,
+                           g_variant_new_byte (ctx->startup_mode));
 
-    /*
-     * If there are no URIs specified, pass an empty string, so that
-     * the primary instance opens a new window.
-     */
-    if (ctx->arguments)
-      g_variant_builder_add (ctx_builder, "{iv}",
-                             CTX_ARGUMENTS,
-                             g_variant_new_strv ((const char **)ctx->arguments, -1));
+  if (ctx->session_filename)
+    g_variant_builder_add (&ctx_builder, "{iv}",
+                           CTX_SESSION_FILENAME,
+                           g_variant_new_string (ctx->session_filename));
 
-    g_variant_builder_add (ctx_builder, "{iv}",
-                           CTX_USER_TIME,
-                           g_variant_new_uint32 (ctx->user_time));
+  /*
+   * If there are no URIs specified, pass an empty string, so that
+   * the primary instance opens a new window.
+   */
+  if (ctx->arguments)
+    g_variant_builder_add (&ctx_builder, "{iv}",
+                           CTX_ARGUMENTS,
+                           g_variant_new_strv ((const char **)ctx->arguments, -1));
 
-    g_variant_builder_add (builder, "{sv}",
-                           "ephy-shell-startup-context",
-                           g_variant_builder_end (ctx_builder));
-
-    g_variant_builder_unref (ctx_builder);
-  }
+  g_variant_builder_add (builder, "{sv}",
+                         "ephy-shell-startup-context",
+                         g_variant_builder_end (&ctx_builder));
 }
 
 static void
@@ -806,9 +821,6 @@ ephy_shell_before_emit (GApplication *application,
           case CTX_ARGUMENTS:
             ctx->arguments = g_variant_dup_strv (ctx_value, NULL);
             break;
-          case CTX_USER_TIME:
-            ctx->user_time = g_variant_get_uint32 (ctx_value);
-            break;
           default:
             g_assert_not_reached ();
             break;
@@ -1030,7 +1042,6 @@ show_notification_cb (WebKitWebView      *web_view,
  * @shell: a #EphyShell
  * @window: the target #EphyWindow or %NULL
  * @previous_embed: the referrer embed, or %NULL
- * @user_time: a timestamp, or 0
  *
  * Create a new tab and the parent window when necessary.
  * Use this function to open urls in new window/tabs.
@@ -1043,8 +1054,7 @@ ephy_shell_new_tab_full (EphyShell       *shell,
                          WebKitWebView   *related_view,
                          EphyWindow      *window,
                          EphyEmbed       *previous_embed,
-                         EphyNewTabFlags  flags,
-                         guint32          user_time)
+                         EphyNewTabFlags  flags)
 {
   EphyEmbedShell *embed_shell;
   GtkWidget *web_view;
@@ -1121,8 +1131,7 @@ ephy_shell_new_tab (EphyShell       *shell,
                     EphyNewTabFlags  flags)
 {
   return ephy_shell_new_tab_full (shell, NULL, NULL, parent_window,
-                                  previous_embed, flags,
-                                  0);
+                                  previous_embed, flags);
 }
 
 /**
@@ -1424,7 +1433,6 @@ typedef struct {
   EphyWindow *window;
   char **uris;
   EphyNewTabFlags flags;
-  guint32 user_time;
   EphyEmbed *previous_embed;
   guint current_uri;
   gboolean reuse_empty_tab;
@@ -1434,8 +1442,7 @@ typedef struct {
 static OpenURIsData *
 open_uris_data_new (EphyShell        *shell,
                     const char      **uris,
-                    EphyStartupMode   startup_mode,
-                    guint32           user_time)
+                    EphyStartupMode   startup_mode)
 {
   OpenURIsData *data;
   gboolean fullscreen_lockdown;
@@ -1445,7 +1452,6 @@ open_uris_data_new (EphyShell        *shell,
   data->shell = shell;
   data->session = session ? g_object_ref (session) : NULL;
   data->uris = g_strdupv ((char **)uris);
-  data->user_time = user_time;
 
   fullscreen_lockdown = g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
                                                 EPHY_PREFS_LOCKDOWN_FULLSCREEN);
@@ -1505,8 +1511,7 @@ ephy_shell_open_uris_idle (OpenURIsData *data)
                                      NULL, NULL,
                                      data->window,
                                      data->previous_embed,
-                                     data->flags | page_flags,
-                                     data->user_time);
+                                     data->flags | page_flags);
   }
 
   if (url_is_xpi) {
@@ -1520,7 +1525,7 @@ ephy_shell_open_uris_idle (OpenURIsData *data)
       gtk_widget_grab_focus (GTK_WIDGET (embed));
 
     if (data->flags & EPHY_NEW_TAB_JUMP && mode != EPHY_EMBED_SHELL_MODE_TEST)
-      gtk_window_present_with_time (GTK_WINDOW (data->window), data->user_time);
+      gtk_window_present (GTK_WINDOW (data->window));
   } else {
     ephy_web_view_load_new_tab_page (ephy_embed_get_web_view (embed));
     if (data->flags & EPHY_NEW_TAB_JUMP)
@@ -1551,15 +1556,14 @@ ephy_shell_open_uris_idle_done (OpenURIsData *data)
 void
 ephy_shell_open_uris (EphyShell        *shell,
                       const char      **uris,
-                      EphyStartupMode   startup_mode,
-                      guint32           user_time)
+                      EphyStartupMode   startup_mode)
 {
   OpenURIsData *data;
   guint id;
 
   g_assert (EPHY_IS_SHELL (shell));
 
-  data = open_uris_data_new (shell, uris, startup_mode, user_time);
+  data = open_uris_data_new (shell, uris, startup_mode);
   id = g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
                         (GSourceFunc)ephy_shell_open_uris_idle,
                         data,
