@@ -22,6 +22,7 @@
 
 #include "config.h"
 
+#include "autofill-view.h"
 #include "clear-data-view.h"
 #include "ephy-data-view.h"
 #include "ephy-embed-shell.h"
@@ -37,16 +38,16 @@
 #include "prefs-extensions-page.h"
 
 struct _EphyPrefsDialog {
-  AdwPreferencesWindow parent_instance;
+  AdwPreferencesDialog parent_instance;
 
   PrefsGeneralPage *general_page;
   GtkWidget *extensions_page;
 };
 
-G_DEFINE_FINAL_TYPE (EphyPrefsDialog, ephy_prefs_dialog, ADW_TYPE_PREFERENCES_WINDOW)
+G_DEFINE_FINAL_TYPE (EphyPrefsDialog, ephy_prefs_dialog, ADW_TYPE_PREFERENCES_DIALOG)
 
 static gboolean
-on_close_request (EphyPrefsDialog *prefs_dialog)
+on_closed (EphyPrefsDialog *prefs_dialog)
 {
   prefs_general_page_on_pd_close_request (prefs_dialog->general_page);
 
@@ -58,22 +59,41 @@ on_close_request (EphyPrefsDialog *prefs_dialog)
   return GDK_EVENT_PROPAGATE;
 }
 
+void
+ephy_prefs_dialog_show_clear_data_view (EphyPrefsDialog *prefs_dialog)
+{
+  AdwNavigationPage *clear_data_view;
+
+  adw_preferences_dialog_set_visible_page_name (ADW_PREFERENCES_DIALOG (prefs_dialog),
+                                                "privacy-page");
+
+  clear_data_view = g_object_new (EPHY_TYPE_CLEAR_DATA_VIEW, NULL);
+  adw_preferences_dialog_push_subpage (ADW_PREFERENCES_DIALOG (prefs_dialog), clear_data_view);
+}
+
 static void
 on_passwords_row_activated (GtkWidget       *privacy_page,
                             EphyPrefsDialog *prefs_dialog)
 {
   AdwNavigationPage *page = g_object_new (EPHY_TYPE_PASSWORDS_VIEW, NULL);
 
-  adw_preferences_window_push_subpage (ADW_PREFERENCES_WINDOW (prefs_dialog), page);
+  adw_preferences_dialog_push_subpage (ADW_PREFERENCES_DIALOG (prefs_dialog), page);
+}
+
+static void
+on_autofill_row_activated (GtkWidget       *privacy_page,
+                           EphyPrefsDialog *prefs_dialog)
+{
+  AdwNavigationPage *page = g_object_new (EPHY_TYPE_AUTOFILL_VIEW, NULL);
+
+  adw_preferences_dialog_push_subpage (ADW_PREFERENCES_DIALOG (prefs_dialog), page);
 }
 
 static void
 on_clear_data_row_activated (GtkWidget       *privacy_page,
                              EphyPrefsDialog *prefs_dialog)
 {
-  AdwNavigationPage *page = g_object_new (EPHY_TYPE_CLEAR_DATA_VIEW, NULL);
-
-  adw_preferences_window_push_subpage (ADW_PREFERENCES_WINDOW (prefs_dialog), page);
+  ephy_prefs_dialog_show_clear_data_view (prefs_dialog);
 }
 
 static void
@@ -83,7 +103,7 @@ on_extension_row_activated (GtkWidget        *extensions_page,
 {
   AdwNavigationPage *page = ADW_NAVIGATION_PAGE (ephy_extension_view_new (extension));
 
-  adw_preferences_window_push_subpage (ADW_PREFERENCES_WINDOW (prefs_dialog), page);
+  adw_preferences_dialog_push_subpage (ADW_PREFERENCES_DIALOG (prefs_dialog), page);
 }
 
 static void
@@ -96,10 +116,10 @@ sync_extensions (EphyPrefsDialog *self)
   if (enable_extensions && !self->extensions_page) {
     self->extensions_page = g_object_new (EPHY_TYPE_PREFS_EXTENSIONS_PAGE, NULL);
     g_signal_connect (self->extensions_page, "extension-row-activated", G_CALLBACK (on_extension_row_activated), self);
-    adw_preferences_window_add (ADW_PREFERENCES_WINDOW (self),
+    adw_preferences_dialog_add (ADW_PREFERENCES_DIALOG (self),
                                 ADW_PREFERENCES_PAGE (self->extensions_page));
   } else if (self->extensions_page) {
-    adw_preferences_window_remove (ADW_PREFERENCES_WINDOW (self),
+    adw_preferences_dialog_remove (ADW_PREFERENCES_DIALOG (self),
                                    ADW_PREFERENCES_PAGE (self->extensions_page));
     g_clear_weak_pointer (&self->extensions_page);
   }
@@ -116,7 +136,8 @@ ephy_prefs_dialog_class_init (EphyPrefsDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, EphyPrefsDialog, general_page);
 
   /* Template file callbacks */
-  gtk_widget_class_bind_template_callback (widget_class, on_close_request);
+  gtk_widget_class_bind_template_callback (widget_class, on_closed);
+  gtk_widget_class_bind_template_callback (widget_class, on_autofill_row_activated);
   gtk_widget_class_bind_template_callback (widget_class, on_passwords_row_activated);
   gtk_widget_class_bind_template_callback (widget_class, on_clear_data_row_activated);
 }
@@ -125,7 +146,6 @@ static void
 ephy_prefs_dialog_init (EphyPrefsDialog *dialog)
 {
   gtk_widget_init_template (GTK_WIDGET (dialog));
-  gtk_window_set_icon_name (GTK_WINDOW (dialog), APPLICATION_ID);
 
   sync_extensions (dialog);
   g_signal_connect_object (EPHY_SETTINGS_WEB,
