@@ -27,6 +27,8 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_PREFS_DIALOG (ephy_prefs_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (EphyPrefsDialog, ephy_prefs_dialog, EPHY, PREFS_DIALOG, AdwPreferencesWindow)
+G_DECLARE_FINAL_TYPE (EphyPrefsDialog, ephy_prefs_dialog, EPHY, PREFS_DIALOG, AdwPreferencesDialog)
+
+void ephy_prefs_dialog_show_clear_data_view (EphyPrefsDialog *prefs_dialog);
 
 G_END_DECLS
