@@ -82,6 +82,7 @@ struct _PrefsGeneralPage {
   GtkWidget *browsing_box;
   GtkWidget *enable_mouse_gesture_row;
   GtkWidget *enable_switch_to_new_tab;
+  GtkWidget *enable_navigation_gestures_row;
 
   /* Languages */
   AdwPreferencesGroup *lang_group;
@@ -176,12 +177,12 @@ language_editor_add_activated (GtkWidget *listbox,
   general_page = EPHY_PREFS_GENERAL_PAGE (gtk_widget_get_ancestor (listbox, EPHY_TYPE_PREFS_GENERAL_PAGE));
 
   if (general_page->add_lang_dialog == NULL) {
-    GtkWindow *prefs_dialog;
+    GtkWindow *window;
     GtkWindow **add_lang_dialog;
 
-    prefs_dialog = GTK_WINDOW (gtk_widget_get_root (GTK_WIDGET (general_page)));
+    window = GTK_WINDOW (gtk_widget_get_root (GTK_WIDGET (general_page)));
     general_page->add_lang_dialog = setup_add_language_dialog (general_page);
-    gtk_window_set_transient_for (GTK_WINDOW (general_page->add_lang_dialog), prefs_dialog);
+    gtk_window_set_transient_for (GTK_WINDOW (general_page->add_lang_dialog), window);
 
     add_lang_dialog = &general_page->add_lang_dialog;
 
@@ -196,13 +197,10 @@ language_editor_add_activated (GtkWidget *listbox,
 static void
 language_editor_add_function_buttons (PrefsGeneralPage *general_page)
 {
-  GtkWidget *row;
-  GtkWidget *label;
+  GtkWidget *row = adw_button_row_new ();
 
-  row = gtk_list_box_row_new ();
-  label = gtk_label_new (_("Add Language"));
-  gtk_list_box_row_set_child (GTK_LIST_BOX_ROW (row), label);
-  gtk_widget_set_size_request (row, -1, 50);
+  adw_preferences_row_set_title (ADW_PREFERENCES_ROW (row), _("Add Language"));
+  adw_button_row_set_start_icon_name (ADW_BUTTON_ROW (row), "list-add-symbolic");
 
   gtk_list_box_append (GTK_LIST_BOX (general_page->lang_listbox), row);
 
@@ -891,12 +889,12 @@ on_manage_webapp_additional_urls_row_activated (GtkWidget        *button,
                                                 PrefsGeneralPage *general_page)
 {
   EphyWebappAdditionalURLsDialog *urls_dialog;
-  GtkWindow *prefs_dialog;
+  GtkWindow *window;
 
   urls_dialog = ephy_webapp_additional_urls_dialog_new ();
-  prefs_dialog = GTK_WINDOW (gtk_widget_get_root (GTK_WIDGET (general_page)));
+  window = GTK_WINDOW (gtk_widget_get_root (GTK_WIDGET (general_page)));
 
-  gtk_window_set_transient_for (GTK_WINDOW (urls_dialog), prefs_dialog);
+  gtk_window_set_transient_for (GTK_WINDOW (urls_dialog), window);
   gtk_window_set_modal (GTK_WINDOW (urls_dialog), TRUE);
   gtk_window_present (GTK_WINDOW (urls_dialog));
 }
@@ -948,6 +946,7 @@ prefs_general_page_class_init (PrefsGeneralPageClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PrefsGeneralPage, browsing_box);
   gtk_widget_class_bind_template_child (widget_class, PrefsGeneralPage, enable_mouse_gesture_row);
   gtk_widget_class_bind_template_child (widget_class, PrefsGeneralPage, enable_switch_to_new_tab);
+  gtk_widget_class_bind_template_child (widget_class, PrefsGeneralPage, enable_navigation_gestures_row);
 
   /* Languages */
   gtk_widget_class_bind_template_child (widget_class, PrefsGeneralPage, lang_group);
@@ -1134,6 +1133,12 @@ setup_general_page (PrefsGeneralPage *general_page)
                    "active",
                    G_SETTINGS_BIND_DEFAULT);
 
+  g_settings_bind (web_settings,
+                   EPHY_PREFS_WEB_ENABLE_NAVIGATION_GESTURES,
+                   general_page->enable_navigation_gestures_row,
+                   "active",
+                   G_SETTINGS_BIND_DEFAULT);
+
   /* ======================================================================== */
   /* ========================== Languages =================================== */
   /* ======================================================================== */
